#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MULTIPLIES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MULTIPLIES_HPP_INCLUDED

#include <boost/simd/operator/include/functions/multiplies.hpp>

#endif
